from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import File, Boolean, Int, Float, String

Cmalign_V0_1_0 = CommandToolBuilder(tool="cmalign", base_command=["cmalign"], inputs=[ToolInput(tag="in_output_alignment_file", input_type=File(optional=True), prefix="-o", doc=InputDocumentation(doc=": output the alignment to file <f>, not stdout")), ToolInput(tag="in_configure_cm_global", input_type=Boolean(optional=True), prefix="-g", doc=InputDocumentation(doc=": configure CM for global alignment [default: local]")), ToolInput(tag="in_opt_acc", input_type=Boolean(optional=True), prefix="--optacc", doc=InputDocumentation(doc=": use the Holmes/Durbin optimal accuracy algorithm  [default]")), ToolInput(tag="in_cy_k", input_type=Boolean(optional=True), prefix="--cyk", doc=InputDocumentation(doc=": use the CYK algorithm")), ToolInput(tag="in_sample", input_type=Boolean(optional=True), prefix="--sample", doc=InputDocumentation(doc=": sample alignment of each seq from posterior distribution")), ToolInput(tag="in_seed", input_type=Int(optional=True), prefix="--seed", doc=InputDocumentation(doc=": w/--sample, set RNG seed to <n> (if 0: one-time arbitrary seed)")), ToolInput(tag="in_not_run_c", input_type=Boolean(optional=True), prefix="--notrunc", doc=InputDocumentation(doc=": do not use truncated alignment algorithm")), ToolInput(tag="in_sub", input_type=Boolean(optional=True), prefix="--sub", doc=InputDocumentation(doc=": build sub CM for columns b/t HMM predicted start/end points")), ToolInput(tag="in_h_banded", input_type=Boolean(optional=True), prefix="--hbanded", doc=InputDocumentation(doc=": accelerate using CM plan 9 HMM derived bands  [default]")), ToolInput(tag="in_tau", input_type=Float(optional=True), prefix="--tau", doc=InputDocumentation(doc=": set tail loss prob for HMM bands to <x>  [1e-7]  (1e-18<x<1)")), ToolInput(tag="in_mx_size", input_type=Int(optional=True), prefix="--mxsize", doc=InputDocumentation(doc=": set maximum allowable DP matrix size to <x> Mb  [1028.0]  (x>0.)")), ToolInput(tag="in_fixed_tau", input_type=Boolean(optional=True), prefix="--fixedtau", doc=InputDocumentation(doc=": do not adjust tau (tighten bands) until mx size is < limit")), ToolInput(tag="in_max_tau", input_type=Int(optional=True), prefix="--maxtau", doc=InputDocumentation(doc=": set max tau <x> when tightening HMM bands  [0.05]  (0<x<0.5)")), ToolInput(tag="in_non_banded", input_type=Boolean(optional=True), prefix="--nonbanded", doc=InputDocumentation(doc=": do not use HMM bands for faster alignment")), ToolInput(tag="in_small", input_type=Boolean(optional=True), prefix="--small", doc=InputDocumentation(doc=": use small memory divide and conquer (d&c) algorithm")), ToolInput(tag="in_s_file", input_type=File(optional=True), prefix="--sfile", doc=InputDocumentation(doc=": dump alignment score information to file <f>")), ToolInput(tag="in_t_file", input_type=File(optional=True), prefix="--tfile", doc=InputDocumentation(doc=": dump individual sequence parsetrees to file <f>")), ToolInput(tag="in_i_file", input_type=File(optional=True), prefix="--ifile", doc=InputDocumentation(doc=": dump information on per-sequence inserts to file <f>")), ToolInput(tag="in_el_file", input_type=File(optional=True), prefix="--elfile", doc=InputDocumentation(doc=": dump information on per-sequence EL inserts to file <f>")), ToolInput(tag="in_map_ali", input_type=File(optional=True), prefix="--mapali", doc=InputDocumentation(doc=": include alignment in file <f> (same ali that CM came from)")), ToolInput(tag="in_map_str", input_type=Boolean(optional=True), prefix="--mapstr", doc=InputDocumentation(doc=": include structure (w/pknots) from <f> from --mapali <f>")), ToolInput(tag="in_noss", input_type=Boolean(optional=True), prefix="--noss", doc=InputDocumentation(doc=": cmbuild --noss option was used w/aln from --mapali <f>")), ToolInput(tag="in_in_format", input_type=String(optional=True), prefix="--informat", doc=InputDocumentation(doc=": assert <seqfile> is in format <s>: no autodetection")), ToolInput(tag="in_out_format", input_type=String(optional=True), prefix="--outformat", doc=InputDocumentation(doc=": output alignment in format <s>  [Stockholm]")), ToolInput(tag="in_dna_out", input_type=Boolean(optional=True), prefix="--dnaout", doc=InputDocumentation(doc=": output alignment as DNA (not RNA) sequence data")), ToolInput(tag="in_no_prob", input_type=Boolean(optional=True), prefix="--noprob", doc=InputDocumentation(doc=": do not include posterior probabilities in the alignment")), ToolInput(tag="in_match_only", input_type=Boolean(optional=True), prefix="--matchonly", doc=InputDocumentation(doc=": include only match columns in output alignment")), ToolInput(tag="in_i_leaved", input_type=Boolean(optional=True), prefix="--ileaved", doc=InputDocumentation(doc=": force output in interleaved Stockholm format")), ToolInput(tag="in_regress", input_type=File(optional=True), prefix="--regress", doc=InputDocumentation(doc=": save regression test data to file <f>")), ToolInput(tag="in_verbose", input_type=Boolean(optional=True), prefix="--verbose", doc=InputDocumentation(doc=": report extra information; mainly useful for debugging")), ToolInput(tag="in_cpu", input_type=Int(optional=True), prefix="--cpu", doc=InputDocumentation(doc=": number of parallel CPU workers to use for multithreads  (n>=0)")), ToolInput(tag="in_options", input_type=Boolean(optional=True), prefix="-options", doc=InputDocumentation(doc="")), ToolInput(tag="in_cm_file", input_type=String(), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_seq_file", input_type=String(), position=1, doc=InputDocumentation(doc=""))], outputs=[ToolOutput(tag="out_output_alignment_file", output_type=File(optional=True), selector=InputSelector(input_to_select="in_output_alignment_file", type_hint=File()), doc=OutputDocumentation(doc=": output the alignment to file <f>, not stdout"))], container="quay.io/biocontainers/infernal:1.1.3--h516909a_0", version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Cmalign_V0_1_0().translate("wdl")

